@@ -15,5 +15,13 @@ class EIndex(Enum):
 
     return EIndex.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EIndex':
+    try:
+      return EIndex[name]
+    except KeyError:
+      return EIndex.SER_UNKNOWN 
+
+
 
 
