@@ -20,5 +20,13 @@ class EReason(Enum):
 
     return EReason.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EReason':
+    try:
+      return EReason[name]
+    except KeyError:
+      return EReason.SER_UNKNOWN 
+
+
 
 
