@@ -13,5 +13,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
