@@ -18,6 +18,7 @@ class EErrorCode(Enum):
   PIN5_FUNCTION_NOT_ACTIVATED=29
   PIN6_FUNCTION_NOT_ACTIVATED=30
   PIN7_FUNCTION_NOT_ACTIVATED=31
+  CONFIGURATION_OUT_OF_MEMORY=128
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -29,5 +30,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
