@@ -15,6 +15,7 @@ class EPin(Enum):
   S0_READER=40
   RFID_D0=43
   RFID_D1=130
+  ANALOG_IN=36
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -26,5 +27,13 @@ class EPin(Enum):
 
     return EPin.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EPin':
+    try:
+      return EPin[name]
+    except KeyError:
+      return EPin.SER_UNKNOWN 
+
+
 
 
