@@ -16,5 +16,13 @@ class EMode(Enum):
 
     return EMode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EMode':
+    try:
+      return EMode[name]
+    except KeyError:
+      return EMode.SER_UNKNOWN 
+
+
 
 
