@@ -1,16 +1,17 @@
+from pyhausbus.de.hausbus.homeassistant.proxy.led.params.EErrorCode import EErrorCode
 import pyhausbus.HausBusUtils as HausBusUtils
 
 class EvError:
   CLASS_ID = 21
   FUNCTION_ID = 255
 
-  def __init__(self,errorCode:int):
+  def __init__(self,errorCode:EErrorCode):
     self.errorCode=errorCode
 
 
   @staticmethod
   def _fromBytes(dataIn:bytearray, offset):
-    return EvError(HausBusUtils.bytesToInt(dataIn, offset))
+    return EvError(EErrorCode._fromBytes(dataIn, offset))
 
   def __str__(self):
     return f"EvError(errorCode={self.errorCode})"
