@@ -9,6 +9,7 @@ class EErrorCode(Enum):
   DATA_CORRUPT=4
   DISCONNECTED=16
   NOT_CONNECTED=17
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -20,5 +21,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
