@@ -19,5 +19,13 @@ class ENewState(Enum):
 
     return ENewState.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'ENewState':
+    try:
+      return ENewState[name]
+    except KeyError:
+      return ENewState.SER_UNKNOWN 
+
+
 
 
