@@ -2,7 +2,9 @@ import pyhausbus.HausBusUtils as HausBusUtils
 from enum import Enum
 
 class EErrorCode(Enum):
+  CONFIGURATION_OUT_OF_MEMORY=128
   CMD_NOT_SUPPORTED=130
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -14,5 +16,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
