@@ -44,5 +44,13 @@ class EDate(Enum):
 
     return EDate.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EDate':
+    try:
+      return EDate[name]
+    except KeyError:
+      return EDate.SER_UNKNOWN 
+
+
 
 
